WITH actors as ( SELECT distinct a.* from persons a,
    moduleoptionalroles mor right join modules m on mor.module_ident = m.module_ident
    where 

    (a.personid = any (m.authors) or 
        a.personid = any (m.maintainers) or
        a.personid = any (m.licensors) or
        a.personid = any (mor.personids)
    )

    and ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'
),

roles as (
    SELECT 'author' as "type", explode_array(authors) as "id" from modules
    WHERE
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'
    UNION ALL
    SELECT 'maintainer' as "type", explode_array(maintainers) as "id" from modules
    WHERE
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'
    UNION ALL
    SELECT 'licensor' as "type", explode_array(licensors) as "id" from modules
    WHERE
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'
    UNION ALL
    SELECT rolename as "type", explode_array(personids) as "id" from roles r join moduleoptionalroles mor on r.roleid = mor.roleid right join modules m on mor.module_ident = m.module_ident
    WHERE
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'
),

subjects as (
    SELECT t.tag as subject from tags t join moduletags tg on t.tagid = tg.tagid join modules m on tg.module_ident = m.module_ident 
    WHERE
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2')

SELECT 
  xmlelement(name "metadata", 
             xmlattributes('http://cnx.rice.edu/mdml' as "xmlns:md",
                           '0.5' as "mdml-version"),
      xmlcomment(E' WARNING! The \'metadata\' section is read only. Do not edit below. Changes to the metadata section in the source will not be saved. '),

      xmlelement(name "md:repository", 'https://legacy-dev.cnx.org/content'),
      xmlelement(name "md:content-url", 'https://legacy-dev.cnx.org/content/' || m.moduleid||'/'|| m.version),

      xmlelement(name "md:content-id", m.moduleid),
      xmlelement(name "md:title", m.name),
      
      xmlelement(name "md:version", m.version),
      xmlelement(name "md:created", m.created),
      xmlelement(name "md:revised", m.revised),
      xmlelement(name "md:language", m.language),

      xmlelement(name "md:license", xmlattributes( l.url as "url"),
        l.name),

     xmlcomment(E' For information on license requirements for use or modification, see license url in the above <md:license> element.
           For information on formatting required attribution, see the URL:
             CONTENT_URL/content_info#cnx_cite_header
           where CONTENT_URL is the value provided above in the <md:content-url> element.
      '),
      

      xmlelement(name "md:actors",
        xmlagg(
            xmlelement(name "md:person", xmlattributes( a.personid as "userid"),
              xmlelement(name "md:firstname", a.firstname),
              xmlelement(name "md:surname", a.surname),
              xmlelement(name "md:fullname", a.fullname),
              xmlelement(name "md:email", a.email))
            )
      ),

      xmlelement(name "md:roles",
        xmlagg(
            xmlelement(name "md:role", xmlattributes( r.type as "type"), r.id) 
            )
      ),
      xmlelement(name "md:abstract", ab.abstract),
      xmlelement(name "md:subjectlist",
        xmlagg(
            xmlelement(name "md:subject", s.subject)
        )
      )

  )
FROM
    actors a, roles r, subjects s, modules m 
        join licenses l on m.licenseid = l.licenseid
        join abstracts ab on m.abstractid = ab.abstractid
WHERE 
    ident_hash(uuid, major_version, minor_version) = '4539ae23-1ccc-421e-9b25-843acbb6c4b0@7.2'

GROUP BY m.moduleid, m.name, m.version, m.created, m.revised, m.language, l.url, l.name, ab.abstract

--
--  <md:subjectlist>
--    <md:subject>Science and Technology</md:subject>
--  </md:subjectlist>
--
--
--
--  
--
--  
--  
--  
--  
--  
--
--  <!-- WARNING! The 'metadata' section is read only. Do not edit above.
--       Changes to the metadata section in the source will not be saved. -->
--</metadata>
--
--  <col:parameters>
--    <col:param name="real-imaginary-notation" value="font"/>
--    <col:param name="and-or-notation"
--               value="propositional-logic"/>
--    <col:param name="gradient-notation" value="text"/>
--    <col:param name="mean-notation" value="bar"/>
--    <col:param name="remainder-notation" value="text"/>
--    <col:param name="conjugate-notation" value="bar"/>
--    <col:param name="imaginary-i-notation" value="i"/>
--    <col:param name="scalar-product-notation"
--               value="angle-bracket"/>
--    <col:param name="print-font-size" value="10pt"/>
--    <col:param name="curl-notation" value="text"/>
--    <col:param name="for-all-equation-layout"
--               value="symbolic"/>
--    <col:param name="vector-notation" value="bold"/>
--    <col:param name="print-paper-size" value="8.5x11"/>
--    <col:param name="print-font" value="computer-modern"/>
--    <col:param name="print-style" value="ccap-economics"/>
--    <col:param name="print-paragraph-spacing"
--               value="compact"/>
--  </col:parameters>
--  
--  <col:content>
--    
--      <col:module document="m64268" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Preface</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Welcome to Economics!</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63579" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63580" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>What Is Economics, and Why Is It Important?</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63581" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Microeconomics and Macroeconomics</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63582" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>How Economists Use Theories and Models to Understand Economic Issues</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63584" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>How To Organize Economies: An Overview of Economic Systems</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Choice in a World of Scarcity</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63593" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Choice in a World of Scarcity</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63594" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.9">
--        <md:title>How Individuals Make Choices Based on Their Budget Constraint</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63610" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.8">
--        <md:title>The Production Possibilities Frontier and Social Choices</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63611" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Confronting Objections to the Economic Approach</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Demand and Supply</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63600" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Demand and Supply</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63601" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Demand, Supply, and Equilibrium in Markets for Goods and Services</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63602" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Shifts in Demand and Supply for Goods and Services</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63603" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Changes in Equilibrium Price and Quantity: The Four-Step Process</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63604" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Price Ceilings and Price Floors</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63605" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Demand, Supply, and Efficiency</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Labor and Financial Markets</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63595" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Labor and Financial Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63596" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.11">
--        <md:title>Demand and Supply at Work in Labor Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63597" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Demand and Supply in Financial Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63599" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>The Market System as an Efficient Mechanism for Information</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Elasticity</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63915" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to Elasticity</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63916" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Price Elasticity of Demand and Price Elasticity of Supply</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63917" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Polar Cases of Elasticity and Constant Elasticity</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63925" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Elasticity and Pricing</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63929" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Elasticity in Areas Other Than Price</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Consumer Choices</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63895" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to Consumer Choices</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63893" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Consumption Choices</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63894" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How Changes in Income and Prices Affect Consumption Choices</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63892" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Behavioral Economics: An Alternative Framework for Consumer Choice</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Production, Costs, and Industry Structure</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63680" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Introduction to Production, Costs, and Industry Structure</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63677" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Explicit and Implicit Costs, and Accounting and Economic Profit</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63678" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.11">
--        <md:title>Production in the Short Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63679" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.13">
--        <md:title>Costs in the Short Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63681" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Production in the Long Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63682" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.9">
--        <md:title>Costs in the Long Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Perfect Competition</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63797" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Perfect Competition</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63837" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Perfect Competition and Why It Matters</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63906" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>How Perfectly Competitive Firms Make Output Decisions</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63836" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Entry and Exit Decisions in the Long Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63896" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Efficiency in Perfectly Competitive Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Monopoly</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63911" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Introduction to a Monopoly</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63913" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How Monopolies Form: Barriers to Entry</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63942" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How a Profit-Maximizing Monopoly Chooses Output and Price</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Monopolistic Competition and Oligopoly</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63855" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Monopolistic Competition and Oligopoly</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63857" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Monopolistic Competition</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63856" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Oligopoly</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Monopoly and Antitrust Policy</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63886" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Monopoly and Antitrust Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63887" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Corporate Mergers</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63888" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Regulating Anticompetitive Behavior</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63889" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Regulating Natural Monopolies</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63891" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Great Deregulation Experiment</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Environmental Protection and Negative Externalities</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63688" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Environmental Protection and Negative Externalities</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63689" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>The Economics of Pollution</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63690" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Command-and-Control Regulation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63691" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Market-Oriented Environmental Tools</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63693" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>The Benefits and Costs of U.S. Environmental Laws</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63695" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>International Environmental Issues</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63696" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>The Tradeoff between Economic Output and Environmental Protection</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Positive Externalities and Public Goods</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63697" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Positive Externalities and Public Goods</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63698" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Why the Private Sector Underinvests in Innovation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63699" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>How Governments Can Encourage Innovation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63700" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Public Goods</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Labor Markets and Income</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63935" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Introduction to Labor Markets and Income</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63937" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.14">
--        <md:title>The Theory of Labor Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63938" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.10">
--        <md:title>Wages and Employment in an Imperfectly Competitive Labor Market</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63939" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.11">
--        <md:title>Market Power on the Supply Side of Labor Markets: Unions</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63940" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.9">
--        <md:title>Bilateral Monopoly</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64067" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.10">
--        <md:title>Employment Discrimination</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64068" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Immigration</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Poverty and Economic Inequality</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63897" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.1">
--        <md:title>Introduction to Poverty and Economic Inequality</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63907" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Drawing the Poverty Line</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63909" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>The Poverty Trap</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63910" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>The Safety Net</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63904" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Income Inequality: Measurement and Causes</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63908" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Government Policies to Reduce Income Inequality</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Information, Risk, and Insurance</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63683" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Information, Risk, and Insurance</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63684" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>The Problem of Imperfect Information and Asymmetric Information</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63685" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Insurance and Imperfect Information</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Financial Markets</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63860" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Financial Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63861" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How Businesses Raise Financial Capital</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63862" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>How Households Supply Financial Capital</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63863" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>How to Accumulate Personal Wealth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Public Economy</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63901" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to Public Economy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63903" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Voter Participation and Costs of Elections</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63902" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Special Interest Politics</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63898" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Flaws in the Democratic System of Government</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The Macroeconomic Perspective</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63717" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to the Macroeconomic Perspective</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63719" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.15">
--        <md:title>Measuring the Size of the Economy: Gross Domestic Product</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63724" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Adjusting Nominal Values to Real Values</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63727" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Tracking Real GDP over Time</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63733" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.8">
--        <md:title>Comparing GDP among Countries</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63734" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>How Well GDP Measures the Well-Being of Society</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Economic Growth</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64104" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Economic Growth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64111" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Relatively Recent Arrival of Economic Growth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64108" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Labor Productivity and Economic Growth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64112" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Components of Economic Growth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64102" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Economic Convergence</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Unemployment</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64096" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Unemployment</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64100" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How Economists Define and Compute Unemployment Rate</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64092" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Patterns of Unemployment</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64090" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>What Causes Changes in Unemployment over the Short Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64098" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.8">
--        <md:title>What Causes Changes in Unemployment over the Long Run</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Inflation</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64150" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64146" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Tracking Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64154" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>How to Measure Changes in the Cost of Living</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64156" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How the U.S. and Other Countries Experience Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64139" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>The Confusion Over Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64138" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Indexing and Its Limitations</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The International Trade and Capital Flows</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64021" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to the International Trade and Capital Flows</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64147" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Measuring Trade Balances</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64152" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Trade Balances in Historical and International Context</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64155" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Trade Balances and Flows of Financial Capital</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64157" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The National Saving and Investment Identity</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64158" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Pros and Cons of Trade Deficits and Surpluses</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64159" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Difference between Level of Trade and the Trade Balance</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The Aggregate Demand/Aggregate Supply Model</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63805" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to the Aggregate Supply–Aggregate Demand Model</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63812" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Macroeconomic Perspectives on Demand and Supply</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63807" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Building a Model of Aggregate Demand and Aggregate Supply</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63808" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Shifts in Aggregate Supply</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63809" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Shifts in Aggregate Demand</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63810" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How the AD/AS Model Incorporates Growth, Unemployment, and Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63811" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Keynes’ Law and Say’s Law in the AD/AS Model</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The Keynesian Perspective</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63849" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to the Keynesian Perspective</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63850" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Aggregate Demand in Keynesian Analysis</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63851" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>The Building Blocks of Keynesian Analysis</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63852" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>The Phillips Curve</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63853" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Keynesian Perspective on Market Forces</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The Neoclassical Perspective</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63798" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to the Neoclassical Perspective</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63802" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>The Building Blocks of Neoclassical Analysis</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63803" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>The Policy Implications of the Neoclassical Perspective</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63804" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Balancing Keynesian and Neoclassical Models</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Money and Banking</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63710" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Money and Banking</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63711" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>Defining Money by Its Functions</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63712" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Measuring Money: Currency, M1, and M2</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63713" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>The Role of Banks</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63714" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>How Banks Create Money</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Monetary Policy and Bank Regulation</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63716" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Derived copy of Introduction to Monetary Policy and Bank Regulation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63726" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Federal Reserve Banking System and Central Banks</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63945" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Bank Regulation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63944" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>How a Central Bank Executes Monetary Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63941" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Monetary Policy and Economic Outcomes</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63943" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Pitfalls for Monetary Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Exchange Rates and International Capital Flows</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64190" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Exchange Rates and International Capital Flows</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64200" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>How the Foreign Exchange Market Works</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64192" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Demand and Supply Shifts in Foreign Exchange Markets</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64196" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Macroeconomic Effects of Exchange Rates</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64198" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Exchange Rate Policies</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Government Budgets and Fiscal Policy</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63969" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to Government Budgets and Fiscal Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63970" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Government Spending</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63971" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Taxation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63972" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Federal Deficits and the National Debt</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63973" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Using Fiscal Policy to Fight Recession, Unemployment, and Inflation</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63974" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Automatic Stabilizers</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63975" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Practical Problems with Discretionary Fiscal Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63976" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Question of a Balanced Budget</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>The Impacts of Government Borrowing</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64113" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Introduction to the Impacts of Government Borrowing</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64118" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>How Government Borrowing Affects Investment and the Trade Balance</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64121" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Fiscal Policy and the Trade Balance</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64114" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>How Government Borrowing Affects Private Saving</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64137" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Fiscal Policy, Investment, and Economic Growth</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Macroeconomic Policy Around the World</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m64022" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Introduction to Macroeconomic Policy around the World</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64130" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Diversity of Countries and Economies across the World</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64133" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Improving Countries’ Standards of Living</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64135" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Causes of Unemployment around the World</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64124" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Causes of Inflation in Various Countries and Regions</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64126" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Balance of Trade Concerns</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>International Trade</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63822" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to International Trade</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63823" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Absolute and Comparative Advantage</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63824" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>What Happens When a Country Has an Absolute Advantage in All Goods</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63825" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.4">
--        <md:title>Intra-industry Trade between Similar Economies</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63826" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>The Benefits of Reducing Barriers to International Trade</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      
--        
--      <col:subcollection>
--        <md:title>Globalization and Protectionism</md:title>
--        
--        
--        
--
--        <col:content>
--          
--    
--      <col:module document="m63827" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>Introduction to Globalization and Protectionism</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63829" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Protectionism: An Indirect Subsidy from Consumers to Producers</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63831" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>International Trade and Its Effects on Jobs, Wages, and Working Conditions</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63833" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>Arguments in Support of Restricting Imports</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63834" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>How Governments Enact Trade Policy: Globally, Regionally, and Nationally</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63835" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.2">
--        <md:title>The Tradeoffs of Trade Policy</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--        </col:content>
--      </col:subcollection>
--    
--    
--      <col:module document="m63990" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.7">
--        <md:title>The Use of Mathematics in Principles of Economics</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63992" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.6">
--        <md:title>Indifference Curves</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m63993" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.5">
--        <md:title>Present Discounted Value</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--    
--      <col:module document="m64270" version="latest"
--                  repository="https://legacy-dev.cnx.org/content"
--                  cnxorg:version-at-this-collection-version="1.3">
--        <md:title>The Expenditure-Output Model</md:title>
--        
--        
--        
--      </col:module>
--        
--      
--    
--  </col:content>
--</col:collection>
